pub enum Error {
StorageError(String),
BadUuidFormat(String),
AlreadySet,
}Expand description
Errors that can occur while retrieving or generating a device ID.
Variants
StorageError(String)
Error with the underlying storage mechanism (file I/O on Unix, or registry on Windows)
BadUuidFormat(String)
Error when parsing the device ID as a UUID
AlreadySet
Error when the device ID is already set and cannot be generated again